@@ -1,19 +1,112 @@
+import warnings
+from typing_extensions import deprecated
 from typing import List, Optional, Sequence
 
-from tsugu_api import settings
-from tsugu_api._network import Api
-from tsugu_api._typing import (
+from tsugu_api_core import settings
+from tsugu_api_core._network import Api
+from tsugu_api_core._typing import (
     _Room,
     _Server,
     _Response,
-    _DifficultyText
+    _ServerId,
+    _DifficultyId,
+    _FuzzySearchResult,
+    _FuzzySearchResponse
 )
 
-def event_stage(server: _Server, event_id: Optional[int] = None, meta: bool = False) -> _Response:
+def cutoff_all(main_server: _ServerId, event_id: Optional[int] = None) -> _Response:
+    '''查询活动排行榜全部预测线
+
+    参数:
+        main_server (_ServerId): 主服务器
+        event_id (int): 活动 ID
+
+    返回:
+        _Response: 响应信息
+    '''
+    
+    # 构建 URL
+    url = settings.backend_url + '/cutoffAll'
+    
+    # 构建数据
+    data = {
+        'mainServer': main_server,
+        'compress': settings.compress
+    }
+    if event_id:
+        data['eventId'] = event_id
+    
+    # 发送请求
+    return Api(
+        url,
+        proxy=settings.backend_proxy
+    ).post(data).json()
+
+def cutoff_detail(main_server: _ServerId, tier: int, event_id: Optional[int] = None) -> _Response:
+    '''查询活动排行榜预测线
+
+    参数:
+        main_server (_ServerId): 主服务器
+        tier (int): 排行榜挡位
+        event_id (int): 活动 ID
+
+    返回:
+        _Response: 响应信息
+    '''
+    
+    # 构建 URL
+    url = settings.backend_url + '/cutoffDetail'
+    
+    # 构建数据
+    data = {
+        'mainServer': main_server,
+        'tier': tier,
+        'compress': settings.compress
+    }
+    if event_id:
+        data['eventId'] = event_id
+    
+    # 发送请求
+    return Api(
+        url,
+        proxy=settings.backend_proxy
+    ).post(data).json()
+
+def cutoff_list_of_recent_event(main_server: _ServerId, tier: int, event_id: Optional[int] = None) -> _Response:
+    '''查询历史活动排行榜预测线
+
+    参数:
+        main_server (_ServerId): 主服务器
+        tier (int): 排行榜挡位
+        event_id (int): 活动 ID
+
+    返回:
+        _Response: 响应信息
+    '''
+    
+    # 构建 URL
+    url = settings.backend_url + '/cutoffListOfRecentEvent'
+    
+    # 构建数据
+    data = {
+        'mainServer': main_server,
+        'tier': tier,
+        'compress': settings.compress
+    }
+    if event_id:
+        data['eventId'] = event_id
+    
+    # 发送请求
+    return Api(
+        url,
+        proxy=settings.backend_proxy
+    ).post(data).json()
+
+def event_stage(main_server: _ServerId, event_id: Optional[int] = None, meta: bool = False) -> _Response:
     '''查询团队 LIVE 佳节活动舞台数据
 
     参数:
-        server (_Server): 服务器
+        main_server (_ServerId): 主服务器
         event_id (int): 活动 ID
         meta (bool): 是否携带歌曲分数表
 
@@ -26,7 +119,7 @@ def event_stage(server: _Server, event_id: Optional[int] = None, meta: bool = Fa
     
     # 构建数据
     data = {
-        'server': server,
+        'mainServer': main_server,
         'meta': meta,
         'compress': settings.compress
     }
@@ -39,11 +132,36 @@ def event_stage(server: _Server, event_id: Optional[int] = None, meta: bool = Fa
         proxy=settings.backend_proxy
     ).post(data).json()
 
-def gacha_simulate(server_mode: _Server, times: Optional[int] = None, gacha_id: Optional[int] = None) -> _Response:
+def fuzzy_search(text: str) -> _FuzzySearchResponse:
+    '''模糊搜索
+
+    参数:
+        text (str): 搜索文本
+
+    返回:
+        _FuzzySearchResponse: 响应信息
+    '''
+    
+    # 构建 URL
+    url = settings.backend_url + '/fuzzySearch'
+    
+    # 构建数据
+    data = {
+        'text': text,
+        'compress': settings.compress
+    }
+    
+    # 发送请求
+    return Api(
+        url,
+        proxy=settings.backend_proxy
+    ).post(data).json()
+
+def gacha_simulate(main_server: _ServerId, times: Optional[int] = None, gacha_id: Optional[int] = None) -> _Response:
     '''模拟抽卡
 
     参数:
-        server_mode (_Server): 服务器模式
+        main_server (_ServerId): 主服务器
         times (int): 抽卡次数
         gacha_id (int): 卡池 ID
 
@@ -56,7 +174,7 @@ def gacha_simulate(server_mode: _Server, times: Optional[int] = None, gacha_id:
     
     # 构建数据
     data = {
-        'server_mode': server_mode,
+        'mainServer': main_server,
         'compress': settings.compress
     }
     if times:
@@ -94,6 +212,7 @@ def get_card_illustration(card_id: int) -> _Response:
         proxy=settings.backend_proxy
     ).post(data).json()
 
+@deprecated("The `lsycx` api is now deprecated, use `cutoff_list_of_recent_event` instead.", category=None)
 def lsycx(server: _Server, tier: int, event_id: Optional[int] = None) -> _Response:
     '''查询历史排行榜预测线
 
@@ -105,24 +224,15 @@ def lsycx(server: _Server, tier: int, event_id: Optional[int] = None) -> _Respon
     返回:
         _Response: 响应信息
     '''
+    warnings.warn(
+        "The `lsycx` api is now deprecated, use `cutoff_list_of_recent_event` instead.",
+        DeprecationWarning
+    )
     
-    # 构建 URL
-    url = settings.backend_url + '/lsycx'
+    if not isinstance(server, int):
+        raise ValueError("'server' must be an integer.")
     
-    # 构建数据
-    data = {
-        'server': server,
-        'tier': tier,
-        'compress': settings.compress
-    }
-    if event_id:
-        data['eventId'] = event_id
-    
-    # 发送请求
-    return Api(
-        url,
-        proxy=settings.backend_proxy
-    ).post(data).json()
+    return cutoff_list_of_recent_event(server, tier, event_id)
 
 def room_list(room_list: List[_Room]) -> _Response:
     '''绘制车牌绘图
@@ -149,12 +259,17 @@ def room_list(room_list: List[_Room]) -> _Response:
         proxy=settings.backend_proxy
     ).post(data).json()
 
-def search_card(default_servers: Sequence[_Server], text: str) -> _Response:
+def search_card(
+    displayed_server_list: Sequence[_ServerId],
+    text: Optional[str] = None,
+    fuzzy_search_result: Optional[_FuzzySearchResult] = None
+) -> _Response:
     '''查询卡片
 
     参数:
-        default_servers (list[_Server]): 默认服务器
-        text (str): 查询参数
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
+        text (str): 查询参数，与 `fuzzy_search_result` 二选一
+        fuzzy_search_result (_FuzzySearchResult): 模糊搜索结果，与 `text` 二选一
 
     返回:
         _Response: 响应信息
@@ -165,11 +280,14 @@ def search_card(default_servers: Sequence[_Server], text: str) -> _Response:
     
     # 构建数据
     data = {
-        'default_servers': default_servers,
-        'text': text,
+        'displayedServerList': displayed_server_list,
         'useEasyBG': settings.use_easy_bg,
         'compress': settings.compress
     }
+    if text:
+        data['text'] = text
+    if fuzzy_search_result:
+        data['fuzzySearchResult'] = fuzzy_search_result
     
     # 发送请求
     return Api(
@@ -177,12 +295,17 @@ def search_card(default_servers: Sequence[_Server], text: str) -> _Response:
         proxy=settings.backend_proxy
     ).post(data).json()
 
-def search_character(default_servers: Sequence[_Server], text: str) -> _Response:
+def search_character(
+    displayed_server_list: Sequence[_ServerId],
+    fuzzy_search_result: Optional[_FuzzySearchResult] = None,
+    text: Optional[str] = None
+) -> _Response:
     '''查询角色
 
     参数:
-        default_servers (list[_Server]): 默认服务器
-        text (str): 查询参数
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
+        fuzzy_search_result (_FuzzySearchResult): 模糊搜索结果，与 `text` 二选一
+        text (str): 查询参数，与 `fuzzy_search_result` 二选一
 
     返回:
         _Response: 响应信息
@@ -193,10 +316,13 @@ def search_character(default_servers: Sequence[_Server], text: str) -> _Response
     
     # 构建数据
     data = {
-        'default_servers': default_servers,
-        'text': text,
+        'displayedServerList': displayed_server_list,
         'compress': settings.compress
     }
+    if fuzzy_search_result:
+        data['fuzzySearchResult'] = fuzzy_search_result
+    if text:
+        data['text'] = text
     
     # 发送请求
     return Api(
@@ -204,12 +330,17 @@ def search_character(default_servers: Sequence[_Server], text: str) -> _Response
         proxy=settings.backend_proxy
     ).post(data).json()
 
-def search_event(default_servers: Sequence[_Server], text: str) -> _Response:
+def search_event(
+    displayed_server_list: Sequence[_ServerId],
+    fuzzy_search_result: Optional[_FuzzySearchResult] = None,
+    text: Optional[str] = None
+) -> _Response:
     '''查询活动
 
     参数:
-        default_servers (list[_Server]): 默认服务器
-        text (str): 查询参数
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
+        fuzzy_search_result (_FuzzySearchResult): 模糊搜索结果，与 `text` 二选一
+        text (str): 查询参数，与 `fuzzy_search_result` 二选一
 
     返回:
         _Response: 响应信息
@@ -220,11 +351,14 @@ def search_event(default_servers: Sequence[_Server], text: str) -> _Response:
     
     # 构建数据
     data = {
-        'default_servers': default_servers,
-        'text': text,
+        'displayedServerList': displayed_server_list,
         'useEasyBG': settings.use_easy_bg,
         'compress': settings.compress
     }
+    if fuzzy_search_result:
+        data['fuzzySearchResult'] = fuzzy_search_result
+    if text:
+        data['text'] = text
     
     # 发送请求
     return Api(
@@ -232,11 +366,14 @@ def search_event(default_servers: Sequence[_Server], text: str) -> _Response:
         proxy=settings.backend_proxy
     ).post(data).json()
 
-def search_gacha(default_servers: Sequence[_Server], gacha_id: int) -> _Response:
+def search_gacha(
+    displayed_server_list: Sequence[_ServerId],
+    gacha_id: int
+) -> _Response:
     '''查询卡池
 
     参数:
-        default_servers (list[_Server]): 默认服务器
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
         gacha_id (int): 卡池 ID
 
     返回:
@@ -248,7 +385,7 @@ def search_gacha(default_servers: Sequence[_Server], gacha_id: int) -> _Response
     
     # 构建数据
     data = {
-        'default_servers': default_servers,
+        'displayedServerList': displayed_server_list,
         'gachaId': gacha_id,
         'useEasyBG': settings.use_easy_bg,
         'compress': settings.compress
@@ -260,12 +397,12 @@ def search_gacha(default_servers: Sequence[_Server], gacha_id: int) -> _Response
         proxy=settings.backend_proxy
     ).post(data).json()
 
-def search_player(player_id: int, server: _Server) -> _Response:
+def search_player(player_id: int, main_server: _ServerId) -> _Response:
     '''查询玩家状态
 
     参数:
         player_id (int): 玩家 ID
-        server (_Server): 服务器
+        main_server (_ServerId): 服务器
 
     返回:
         _Response: 响应信息
@@ -277,7 +414,7 @@ def search_player(player_id: int, server: _Server) -> _Response:
     # 构建数据
     data = {
         'playerId': player_id,
-        'server': server,
+        'mainServer': main_server,
         'useEasyBG': settings.use_easy_bg,
         'compress': settings.compress
     }
@@ -288,12 +425,17 @@ def search_player(player_id: int, server: _Server) -> _Response:
         proxy=settings.backend_proxy
     ).post(data).json()
 
-def search_song(default_servers: Sequence[_Server], text: str) -> _Response:
+def search_song(
+    displayed_server_list: Sequence[_ServerId],
+    fuzzy_search_result: Optional[_FuzzySearchResult] = None,
+    text: Optional[str] = None
+) -> _Response:
     '''查询歌曲
 
     参数:
-        default_servers (list[_Server]): 默认服务器
-        text (str): 查询参数
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
+        fuzzy_search_result (_FuzzySearchResult): 模糊搜索结果，与 `text` 二选一
+        text (str): 查询参数，与 `fuzzy_search_result` 二选一
 
     返回:
         _Response: 响应信息
@@ -304,10 +446,13 @@ def search_song(default_servers: Sequence[_Server], text: str) -> _Response:
     
     # 构建数据
     data = {
-        'default_servers': default_servers,
-        'text': text,
+        'displayedServerList': displayed_server_list,
         'compress': settings.compress
     }
+    if fuzzy_search_result:
+        data['fuzzySearchResult'] = fuzzy_search_result
+    if text:
+        data['text'] = text
     
     # 发送请求
     return Api(
@@ -315,13 +460,17 @@ def search_song(default_servers: Sequence[_Server], text: str) -> _Response:
         proxy=settings.backend_proxy
     ).post(data).json()
 
-def song_chart(default_servers: Sequence[_Server], song_id: int, difficulty_text: _DifficultyText) -> _Response:
+def song_chart(
+    displayed_server_list: Sequence[_ServerId],
+    song_id: int,
+    difficulty_id: _DifficultyId
+) -> _Response:
     '''查询歌曲谱面
 
     参数:
-        default_servers (list[_Server]): 默认服务器
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
         song_id (int): 歌曲 ID
-        difficulty_text (_Difficulty): 谱面难度
+        difficulty_id (_DifficultyId): 难度 ID
 
     返回:
         _Response: 响应信息
@@ -332,9 +481,9 @@ def song_chart(default_servers: Sequence[_Server], song_id: int, difficulty_text
     
     # 构建数据
     data = {
-        'default_servers': default_servers,
+        'displayedServerList': displayed_server_list,
         'songId': song_id,
-        'difficultyText': difficulty_text,
+        'difficultyId': difficulty_id,
         'compress': settings.compress
     }
     
@@ -344,12 +493,15 @@ def song_chart(default_servers: Sequence[_Server], song_id: int, difficulty_text
         proxy=settings.backend_proxy
     ).post(data).json()
 
-def song_meta(default_servers: Sequence[_Server], server: _Server) -> _Response:
+def song_meta(
+    displayed_server_list: Sequence[_ServerId],
+    main_server: _ServerId
+) -> _Response:
     '''查询歌曲分数表
 
     参数:
-        default_servers (list[_Server]): 默认服务器
-        server (_Server): 主服务器
+        displayed_server_list (Sequence[_ServerId]): 展示服务器
+        main_server (_ServerId): 主服务器
 
     返回:
         _Response: 响应信息
@@ -360,8 +512,8 @@ def song_meta(default_servers: Sequence[_Server], server: _Server) -> _Response:
     
     # 构建数据
     data = {
-        'default_servers': default_servers,
-        'server': server,
+        'displayedServerList': displayed_server_list,
+        'mainServer': main_server,
         'compress': settings.compress
     }
     
@@ -371,6 +523,7 @@ def song_meta(default_servers: Sequence[_Server], server: _Server) -> _Response:
         proxy=settings.backend_proxy
     ).post(data).json()
 
+@deprecated("The `ycx` api is now deprecated, use `cutoff_detail` instead.", category=None)
 def ycx(server: _Server, tier: int, event_id: Optional[int] = None) -> _Response:
     '''查询排行榜预测线
 
@@ -382,25 +535,17 @@ def ycx(server: _Server, tier: int, event_id: Optional[int] = None) -> _Response
     返回:
         _Response: 响应信息
     '''
+    warnings.warn(
+        "The `ycx` api is now deprecated, use `cutoff_detail` instead.",
+        DeprecationWarning
+    )
     
-    # 构建 URL
-    url = settings.backend_url + '/ycx'
+    if not isinstance(server, int):
+        raise ValueError("'server' must be an integer.")
     
-    # 构建数据
-    data = {
-        'server': server,
-        'tier': tier,
-        'compress': settings.compress
-    }
-    if event_id:
-        data['eventId'] = event_id
-    
-    # 发送请求
-    return Api(
-        url,
-        proxy=settings.backend_proxy
-    ).post(data).json()
+    return cutoff_detail(server, tier, event_id)
 
+@deprecated("The `ycx_all` api is now deprecated, use `cutoff_all` instead.", category=None)
 def ycx_all(server: _Server, event_id: Optional[int] = None) -> _Response:
     '''查询全挡位预测线
 
@@ -411,20 +556,12 @@ def ycx_all(server: _Server, event_id: Optional[int] = None) -> _Response:
     返回:
         _Response: 响应信息
     '''
+    warnings.warn(
+        "The `ycx_all` api is now deprecated, use `cutoff_all` instead.",
+        DeprecationWarning
+    )
     
-    # 构建 URL
-    url = settings.backend_url + '/ycxAll'
+    if not isinstance(server, int):
+        raise ValueError("'server' must be an integer.")
     
-    # 构建数据
-    data = {
-        'server': server,
-        'compress': settings.compress
-    }
-    if event_id:
-        data['eventId'] = event_id
-    
-    # 发送请求
-    return Api(
-        url,
-        proxy=settings.backend_proxy
-    ).post(data).json()
+    return cutoff_all(server, event_id)
