@@ -1,10 +1,9 @@
-from typing import Union
-
-from tsugu_api import settings
-from tsugu_api._network import Api
-from tsugu_api._typing import (
-    _Update,
+from tsugu_api_core import settings
+from tsugu_api_core._network import Api
+from tsugu_api_core._typing import (
     _ServerId,
+    _BindingAction,
+    _PartialTsuguUser,
     _GetUserDataResponse,
     _ChangeUserDataResponse,
     _BindPlayerRequestResponse,
@@ -28,7 +27,7 @@ def get_user_data(platform: str, user_id: str) -> _GetUserDataResponse:
     # 构建数据
     data = {
         'platform': platform,
-        'user_id': user_id
+        'userId': user_id
     }
     
     # 发送请求
@@ -37,13 +36,13 @@ def get_user_data(platform: str, user_id: str) -> _GetUserDataResponse:
         proxy=settings.userdata_backend_proxy
     ).post(data).json()
 
-def change_user_data(platform: str, user_id: str, update: _Update) -> _ChangeUserDataResponse:
+def change_user_data(platform: str, user_id: str, update: _PartialTsuguUser) -> _ChangeUserDataResponse:
     '''修改用户数据
 
     参数:
         platform (str): 平台名称
         user_id (str): 用户 ID
-        update (_Update): 更新数据
+        update (_PartialTsuguUser): 更新数据
 
     返回:
         _ChangeUserDataResponse: API 返回响应
@@ -55,7 +54,7 @@ def change_user_data(platform: str, user_id: str, update: _Update) -> _ChangeUse
     # 构建数据
     data = {
         'platform': platform,
-        'user_id': user_id,
+        'userId': user_id,
         'update': update
     }
     
@@ -67,17 +66,13 @@ def change_user_data(platform: str, user_id: str, update: _Update) -> _ChangeUse
 
 def bind_player_request(
     platform: str,
-    user_id: str,
-    server: _ServerId,
-    bind_type: bool
+    user_id: str
 ) -> _BindPlayerRequestResponse:
     '''绑定玩家请求
 
     参数:
         platform (str): 平台名称
         user_id (str): 用户 ID
-        server (_ServerId): 服务器编号 0 - 日服 1 - 国际服 2 - 台服 3 - 国服 4 - 韩服
-        bind_type (bool): 绑定类型， `true` 为绑定， `false` 为解绑
 
     返回:
         _BindPlayerRequestResponse: 请求返回数据
@@ -89,9 +84,7 @@ def bind_player_request(
     # 构建数据
     data = {
         'platform': platform,
-        'user_id': user_id,
-        'server': server,
-        'bindType': bind_type
+        'userId': user_id
     }
     
     # 发送请求
@@ -105,7 +98,7 @@ def bind_player_verification(
     user_id: str,
     server: _ServerId,
     player_id: int,
-    bind_type: bool
+    binding_action: _BindingAction
 ) -> _BindPlayerVerificationResponse:
     '''绑定玩家验证
 
@@ -114,7 +107,7 @@ def bind_player_verification(
         user_id (str): 用户 ID
         server (_ServerId): 服务器编号 0 - 日服 1 - 国际服 2 - 台服 3 - 国服 4 - 韩服
         player_id (int): 玩家 ID
-        bind_type (bool): 绑定类型， `true` 为绑定， `false` 为解绑
+        binding_action (_BindingAction): 绑定操作
 
     返回:
         _BindPlayerVerificationResponse: 验证返回数据
@@ -126,10 +119,10 @@ def bind_player_verification(
     # 构建数据
     data = {
         'platform': platform,
-        'user_id': user_id,
+        'userId': user_id,
         'server': server,
         'playerId': player_id,
-        'bindType': bind_type
+        'bindingAction': binding_action
     }
     
     # 发送请求
